@@ -46,7 +46,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Domain"),
             # иконка для графической консоли
-            'image': 'network-server,network-workgroup',
+            'image': 'calculate-client,network-server,network-workgroup',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -64,7 +64,6 @@ class Wsdl(WsdlBase):
                              ClientError, DesktopError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'domain',
-                        'cl_protect_use_set!': 'off'
                         },
             'guivars': {'cl_localhost_set!': lambda dv: (
                 "on" if dv.Get('cl_remote_host') == '' else 'off')},
@@ -91,7 +90,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Domain User Login"),
             # иконка для графической консоли
-            'image': 'application-other',
+            'image': 'calculate-client-sync-login,application-other',
             # метод не присутствует в графической консоли
             'gui': False,
             # консольная команда
@@ -125,7 +124,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Domain User Logout"),
             # иконка для графической консоли
-            'image': 'application-other',
+            'image': 'calculate-client-sync-logout,application-other',
             # метод не присутствует в графической консоли
             'gui': False,
             # консольная команда
@@ -159,7 +158,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Password Modification"),
             # иконка для графической консоли
-            'image': 'preferences-system-privacy,system-users',
+            'image': 'calculate-client-passwd,preferences-system-privacy,system-users',
             # метод присутствует в графической консоли
             'gui': True,
             # пользовательский метода
